@@ -9,7 +9,9 @@ from numbers import Number
 
 import matplotlib.pyplot as plt  # type: ignore
 import numpy as np
-from sympy import Expr, Symbol, lambdify, oo, symbols  # type: ignore
+from rich.console import Console
+from rich.table import Table
+from sympy import Expr, Rational, Symbol, lambdify, oo, symbols  # type: ignore
 from sympy.physics.continuum_mechanics.beam import Beam as SymBeam  # type: ignore
 
 from simplebeam.exceptions import (
@@ -281,17 +283,21 @@ class Beam:
 
         self._restraints.sort(key=lambda x: x.position)
 
+        # Note - using the call to sympy Rational to avoid issues that can cause the
+        # solver to error out on indeterminate beams when floats are used as input.
         for load in self.loads:
-            beam.apply_load(
-                value=load.magnitude, start=load.start, order=load.order, end=load.end
-            )
+            value = Rational(load.magnitude)
+            start = Rational(load.start)
+            end = None if load.end is None else Rational(load.end)
+
+            beam.apply_load(value=value, start=start, order=load.order, end=end)
 
         for restraint in self.restraints:
             if restraint.dy:
                 beam.bc_deflection.append((restraint.position, 0))
                 beam.apply_load(
                     _restraint_symbol(position=restraint.position, prefix="F"),
-                    restraint.position,
+                    Rational(restraint.position),
                     order=-1,
                 )
 
@@ -299,7 +305,7 @@ class Beam:
                 beam.bc_slope.append((restraint.position, 0))
                 beam.apply_load(
                     _restraint_symbol(position=restraint.position, prefix="M"),
-                    restraint.position,
+                    Rational(restraint.position),
                     order=-2,
                 )
 
@@ -405,6 +411,11 @@ class Beam:
         :return: a sympy object describing the results along the beam.
         """
 
+        if not self.solved:
+            raise BeamNotSolvedError(BEAM_NOT_SOLVED_WARNING)
+        if self._symbeam is None:
+            raise BeamNotSolvedError(BEAM_NOT_SOLVED_WARNING)
+
         eqn: Expr
 
         result_type = ResultType(result_type)
@@ -595,8 +606,8 @@ class Beam:
                 x.append(xk)
                 y.append(eq.subs(symbol, xk).evalf())
 
-        xy = sorted(zip(x, y), key=lambda l: l[0])
-        x, y = (list(p) for p in zip(*xy))
+        xy = sorted(zip(x, y, strict=True), key=lambda l: l[0])
+        x, y = (list(p) for p in zip(*xy, strict=True))
 
         x, y = clean_points(x_coords=x, y_coords=y, x_to_keep=list(x_key))
 
@@ -737,12 +748,13 @@ class Beam:
             fast=fast,
         )
 
-    def plot_results(
+    def plot_results(  # pylint: disable=R0913
         self,
         result_type: ResultType | str,
         min_points: int = 101,
         user_points: list[float] | float | None = None,
         fast: bool = True,
+        annotation: bool = True,
     ):
         """
         Plot the results along the length of the beam.
@@ -755,6 +767,7 @@ class Beam:
             use an adaptive algorithm to try and find any singularities in the beam
             curves. If the fast method doesn't give correct results,
             consider trying the slow method.
+        :param annotation: Annotate key points (max & minimum positions)
         """
 
         result_map = {
@@ -774,22 +787,20 @@ class Beam:
         match result_type:
             case ResultType.LOAD:
                 curve = self._load_curve
-                y_label = "Load"
             case ResultType.SHEAR:
                 curve = self.shear_curve
-                y_label = "Shear"
             case ResultType.MOMENT:
                 curve = self.moment_curve
-                y_label = "Moment"
             case ResultType.SLOPE:
                 curve = self.slope_curve
-                y_label = "Slope"
             case ResultType.DEFLECTION:
                 curve = self.deflection_curve
-                y_label = "Deflection"
             case _:
                 raise ResultError("Invalid Result Type Requested")
 
+        y_label = f"{result_type.value.capitalize()}"
+        ax_title = f"{result_type.value.capitalize()} Along Beam"
+
         x, y = curve(min_points=min_points, user_points=user_points, fast=fast)
 
         fig, ax = plt.subplots()
@@ -798,10 +809,365 @@ class Beam:
         ax.fill_between(x, y, alpha=0.3)
         ax.set_xlabel("Length")
         ax.set_ylabel(y_label)
+        ax.set_title(ax_title)
         ax.grid(True)
 
+        if annotation:
+            y_max = max(y)
+            y_min = min(y)
+
+            x_max = x[y.index(y_max)]
+            x_min = x[y.index(y_min)]
+
+            x_max_ann_dir = 1 if x_max < 0.75 * self.length else -0.25
+            x_min_ann_dir = 1 if x_min < 0.75 * self.length else -0.25
+
+            def annotate(*, x_ann, y_ann, x_pos, y_pos, ann_ax=None):
+                """
+                Helper method to annotate the plot
+                """
+
+                if not ann_ax:
+                    ann_ax = plt.gca()
+
+                text = f"{y_ann:.2e} at position {x_ann:.3f}"
+
+                bbox_props = {
+                    "boxstyle": "square,pad=0.3",
+                    "fc": "w",
+                    "ec": "k",
+                    "lw": 0.72,
+                }
+                arrow_props = {"arrowstyle": "-", "connectionstyle": "angle,angleA=60"}
+                kw = {
+                    "xycoords": "data",
+                    "textcoords": "offset points",
+                    "arrowprops": arrow_props,
+                    "bbox": bbox_props,
+                    "ha": "right",
+                    "va": "top",
+                    "fontsize": 8,
+                }
+
+                ann_ax.annotate(text, xy=(x_ann, y_ann), xytext=(x_pos, y_pos), **kw)
+
+            annotate(
+                x_ann=x_min, y_ann=y_min, ann_ax=ax, x_pos=x_min_ann_dir * 100, y_pos=20
+            )
+            annotate(
+                x_ann=x_max,
+                y_ann=y_max,
+                ann_ax=ax,
+                x_pos=x_max_ann_dir * 100,
+                y_pos=-20,
+            )
+
         fig.show()
 
+    def _plot_load(
+        self,
+        min_points: int = 101,
+        user_points: list[float] | float | None = None,
+        fast: bool = True,
+        annotation: bool = True,
+    ):
+        """
+        Plot the load along the length of the beam.
+
+        NOTE: Private method because the load plot does not include
+        point loads / moments.
+
+        :param min_points: The minimum no. of points to return.
+        :param user_points: Points to keep at user defined locations.
+        :param fast: If fast, only evaluate at min_points and user_points. If not fast,
+            use an adaptive algorithm to try and find any singularities in the beam
+            curves. If the fast method doesn't give correct results,
+            consider trying the slow method.
+        :param annotation: Annotate key points (max & minimum positions)
+        """
+
+        self.plot_results(
+            result_type=ResultType.LOAD,
+            min_points=min_points,
+            user_points=user_points,
+            fast=fast,
+            annotation=annotation,
+        )
+
+    def plot_shear(
+        self,
+        min_points: int = 101,
+        user_points: list[float] | float | None = None,
+        fast: bool = True,
+        annotation: bool = True,
+    ):
+        """
+        Plot the shear along the length of the beam.
+
+        :param min_points: The minimum no. of points to return.
+        :param user_points: Points to keep at user defined locations.
+        :param fast: If fast, only evaluate at min_points and user_points. If not fast,
+            use an adaptive algorithm to try and find any singularities in the beam
+            curves. If the fast method doesn't give correct results,
+            consider trying the slow method.
+        :param annotation: Annotate key points (max & minimum positions)
+        """
+
+        self.plot_results(
+            result_type=ResultType.SHEAR,
+            min_points=min_points,
+            user_points=user_points,
+            fast=fast,
+            annotation=annotation,
+        )
+
+    def plot_moment(
+        self,
+        min_points: int = 101,
+        user_points: list[float] | float | None = None,
+        fast: bool = True,
+        annotation: bool = True,
+    ):
+        """
+        Plot the moment along the length of the beam.
+
+        :param min_points: The minimum no. of points to return.
+        :param user_points: Points to keep at user defined locations.
+        :param fast: If fast, only evaluate at min_points and user_points. If not fast,
+            use an adaptive algorithm to try and find any singularities in the beam
+            curves. If the fast method doesn't give correct results,
+            consider trying the slow method.
+        :param annotation: Annotate key points (max & minimum positions)
+        """
+
+        self.plot_results(
+            result_type=ResultType.MOMENT,
+            min_points=min_points,
+            user_points=user_points,
+            fast=fast,
+            annotation=annotation,
+        )
+
+    def plot_slope(
+        self,
+        min_points: int = 101,
+        user_points: list[float] | float | None = None,
+        fast: bool = True,
+        annotation: bool = True,
+    ):
+        """
+        Plot the slope along the length of the beam.
+
+        :param min_points: The minimum no. of points to return.
+        :param user_points: Points to keep at user defined locations.
+        :param fast: If fast, only evaluate at min_points and user_points. If not fast,
+            use an adaptive algorithm to try and find any singularities in the beam
+            curves. If the fast method doesn't give correct results,
+            consider trying the slow method.
+        :param annotation: Annotate key points (max & minimum positions)
+        """
+
+        self.plot_results(
+            result_type=ResultType.SLOPE,
+            min_points=min_points,
+            user_points=user_points,
+            fast=fast,
+            annotation=annotation,
+        )
+
+    def plot_deflection(
+        self,
+        min_points: int = 101,
+        user_points: list[float] | float | None = None,
+        fast: bool = True,
+        annotation: bool = True,
+    ):
+        """
+        Plot the deflection along the length of the beam.
+
+        :param min_points: The minimum no. of points to return.
+        :param user_points: Points to keep at user defined locations.
+        :param fast: If fast, only evaluate at min_points and user_points. If not fast,
+            use an adaptive algorithm to try and find any singularities in the beam
+            curves. If the fast method doesn't give correct results,
+            consider trying the slow method.
+        :param annotation: Annotate key points (max & minimum positions)
+        """
+
+        self.plot_results(
+            result_type=ResultType.DEFLECTION,
+            min_points=min_points,
+            user_points=user_points,
+            fast=fast,
+            annotation=annotation,
+        )
+
+    def reaction_summary(self):
+        """
+        Return a summary of reactions on the beam in tabular form.
+        """
+
+        table = Table(title="Reactions", expand=True)
+        table.add_column("Position", justify="center")
+        table.add_column("Force", justify="center")
+        table.add_column("Moment", justify="center")
+
+        max_force = None
+        max_moment = None
+        min_force = None
+        min_moment = None
+
+        for i, r in self.reactions.items():
+            rest = self.restraints[i]
+
+            if r["F"] is not None:
+                max_force = r["F"] if max_force is None else max(max_force, r["F"])
+                min_force = r["F"] if min_force is None else min(min_force, r["F"])
+            if r["M"] is not None:
+                max_moment = r["M"] if max_moment is None else max(max_moment, r["M"])
+                min_moment = r["M"] if min_moment is None else min(min_moment, r["M"])
+
+            table.add_row(
+                f"{rest.position:.3e}",
+                f"{r['F']:{'' if r['F'] is None else '.3e'}}",
+                f"{r['M']:{'' if r['M'] is None else '.3e'}}",
+            )
+
+        table.add_section()
+
+        table.add_row(
+            "Max.",
+            f"{max_force:{'' if max_force is None else '.3e'}}",
+            f"{max_moment:{'' if max_moment is None else '.3e'}}",
+        )
+        table.add_row(
+            "Min.",
+            f"{min_force:{'' if min_force is None else '.3e'}}",
+            f"{min_moment:{'' if min_moment is None else '.3e'}}",
+        )
+
+        console = Console()
+        console.print(table)
+
+    def result_summary(
+        self,
+        min_points: int = 5,
+        user_points: list[float] | float | None = None,
+        fast: bool = True,
+    ):
+        """
+        Display a summary table of results along the beam.
+
+        :param min_points: The minimum no. of points to return.
+        :param user_points: Points to keep at user defined locations.
+        :param fast: If fast, only evaluate at min_points and user_points. If not fast,
+            use an adaptive algorithm to try and find any singularities in the beam
+            curves. If the fast method doesn't give correct results,
+            consider trying the slow method.
+        """
+
+        table = Table(title="Results", expand=True)
+        table.add_column("Position", justify="center")
+        table.add_column("Shear", justify="center")
+        table.add_column("Moment", justify="center")
+        table.add_column("Slope", justify="center")
+        table.add_column("Deflection", justify="center")
+
+        def process_curve(curve):
+            """
+            Process curves in case there are multiple y values for a single x value.
+            """
+
+            xc, yc = curve
+
+            min_y = min(yc)
+            max_y = max(yc)
+
+            x_dict = {}
+
+            for xi, yi in zip(xc, yc, strict=True):
+                if xi not in x_dict:
+                    x_dict[xi] = []
+
+                x_dict[xi].append(yi)
+
+            xc = sorted(x_dict)
+            yc = [x_dict[xi] for xi in xc]
+
+            return xc, yc, min_y, max_y
+
+        shear = process_curve(
+            self.shear_curve(min_points=min_points, user_points=user_points, fast=fast)
+        )
+        moment = process_curve(
+            self.moment_curve(min_points=min_points, user_points=user_points, fast=fast)
+        )
+        slope = process_curve(
+            self.slope_curve(min_points=min_points, user_points=user_points, fast=fast)
+        )
+        deflection = process_curve(
+            self.deflection_curve(
+                min_points=min_points, user_points=user_points, fast=fast
+            )
+        )
+
+        if len(shear[0]) != len(moment[0]):
+            raise ResultError("Expected shear & moment summaries to be the same length")
+        if len(shear[0]) != len(slope[0]):
+            raise ResultError("Expected shear & slope summaries to be the same length")
+        if len(shear[0]) != len(deflection[0]):
+            raise ResultError(
+                "Expected shear & deflection summaries to be the same length"
+            )
+
+        if set(shear[0]) != set(moment[0]):
+            raise ResultError(
+                "Expected shear and moment summaries to have the same x values"
+            )
+        if set(shear[0]) != set(slope[0]):
+            raise ResultError(
+                "Expected shear and slope summaries to have the same x values"
+            )
+        if set(shear[0]) != set(deflection[0]):
+            raise ResultError(
+                "Expected shear and deflection summaries to have the same x values"
+            )
+
+        for i in range(len(shear[0])):
+            x = shear[0][i]
+            y_shear = " / ".join([f"{y:.3e}" for y in shear[1][i]])
+            y_moment = " / ".join([f"{y:.3e}" for y in moment[1][i]])
+            y_slope = " / ".join([f"{y:.3e}" for y in slope[1][i]])
+            y_deflection = " / ".join([f"{y:.3e}" for y in deflection[1][i]])
+
+            table.add_row(
+                f"{x:.3e}",
+                f"{y_shear}",
+                f"{y_moment}",
+                f"{y_slope}",
+                f"{y_deflection}",
+            )
+
+        table.add_section()
+
+        table.add_row(
+            "Max",
+            f"{shear[3]:.3e}",
+            f"{moment[3]:.3e}",
+            f"{slope[3]:.3e}",
+            f"{deflection[3]:.3e}",
+        )
+        table.add_row(
+            "Min",
+            f"{shear[2]:.3e}",
+            f"{moment[2]:.3e}",
+            f"{slope[2]:.3e}",
+            f"{deflection[2]:.3e}",
+        )
+
+        console = Console()
+        console.print(table)
+
     def __repr__(self):
         restraints = [r.short_name for r in self.restraints]
 
